@@ -1003,7 +1003,13 @@ module.exports = {
 		"10.3.1",
 		"10.3.2",
 		"10.4.0",
-		"10.4.1"
+		"10.4.1",
+		"10.4.2",
+		"10.4.3",
+		"10.4.4",
+		"10.4.5",
+		"10.4.6",
+		"10.4.7"
 	],
 	"86.0.4234.0": [
 		"11.0.0-beta.1",
@@ -1109,7 +1115,21 @@ module.exports = {
 		"11.2.1",
 		"11.2.2",
 		"11.2.3",
-		"11.3.0"
+		"11.3.0",
+		"11.4.0",
+		"11.4.1",
+		"11.4.2",
+		"11.4.3",
+		"11.4.4",
+		"11.4.5",
+		"11.4.6",
+		"11.4.7",
+		"11.4.8",
+		"11.4.9",
+		"11.4.10",
+		"11.4.11",
+		"11.4.12",
+		"11.5.0"
 	],
 	"89.0.4328.0": [
 		"12.0.0-beta.1",
@@ -1192,6 +1212,34 @@ module.exports = {
 	"89.0.4389.82": [
 		"12.0.1"
 	],
+	"89.0.4389.90": [
+		"12.0.2"
+	],
+	"89.0.4389.114": [
+		"12.0.3",
+		"12.0.4"
+	],
+	"89.0.4389.128": [
+		"12.0.5",
+		"12.0.6",
+		"12.0.7",
+		"12.0.8",
+		"12.0.9",
+		"12.0.10",
+		"12.0.11",
+		"12.0.12",
+		"12.0.13",
+		"12.0.14",
+		"12.0.15",
+		"12.0.16",
+		"12.0.17",
+		"12.0.18",
+		"12.1.0",
+		"12.1.1",
+		"12.1.2",
+		"12.2.0",
+		"12.2.1"
+	],
 	"90.0.4402.0": [
 		"13.0.0-beta.2",
 		"13.0.0-beta.3",
@@ -1214,6 +1262,12 @@ module.exports = {
 		"13.0.0-beta.4",
 		"13.0.0-beta.5",
 		"13.0.0-beta.6",
+		"13.0.0-beta.7",
+		"13.0.0-beta.8",
+		"13.0.0-beta.9",
+		"13.0.0-beta.11",
+		"13.0.0-beta.12",
+		"13.0.0-beta.13",
 		"14.0.0-nightly.20210305",
 		"14.0.0-nightly.20210308",
 		"14.0.0-nightly.20210309",
@@ -1222,7 +1276,39 @@ module.exports = {
 		"14.0.0-nightly.20210316",
 		"14.0.0-nightly.20210317",
 		"14.0.0-nightly.20210318",
-		"14.0.0-nightly.20210319"
+		"14.0.0-nightly.20210319",
+		"14.0.0-nightly.20210323",
+		"14.0.0-nightly.20210324",
+		"14.0.0-nightly.20210325",
+		"14.0.0-nightly.20210326",
+		"14.0.0-nightly.20210329",
+		"14.0.0-nightly.20210330"
+	],
+	"91.0.4448.0": [
+		"13.0.0-beta.14",
+		"13.0.0-beta.16",
+		"13.0.0-beta.17",
+		"13.0.0-beta.18",
+		"13.0.0-beta.20",
+		"14.0.0-nightly.20210331",
+		"14.0.0-nightly.20210401",
+		"14.0.0-nightly.20210402",
+		"14.0.0-nightly.20210406",
+		"14.0.0-nightly.20210407",
+		"14.0.0-nightly.20210408",
+		"14.0.0-nightly.20210409",
+		"14.0.0-nightly.20210413"
+	],
+	"91.0.4472.33": [
+		"13.0.0-beta.21",
+		"13.0.0-beta.22",
+		"13.0.0-beta.23"
+	],
+	"91.0.4472.38": [
+		"13.0.0-beta.24",
+		"13.0.0-beta.26",
+		"13.0.0-beta.27",
+		"13.0.0-beta.28"
 	],
 	"89.0.4349.0": [
 		"13.0.0-nightly.20201215",
@@ -1253,5 +1339,266 @@ module.exports = {
 		"13.0.0-nightly.20210205",
 		"13.0.0-nightly.20210208",
 		"13.0.0-nightly.20210209"
+	],
+	"91.0.4472.69": [
+		"13.0.0",
+		"13.0.1"
+	],
+	"91.0.4472.77": [
+		"13.1.0",
+		"13.1.1",
+		"13.1.2"
+	],
+	"91.0.4472.106": [
+		"13.1.3",
+		"13.1.4"
+	],
+	"91.0.4472.124": [
+		"13.1.5",
+		"13.1.6",
+		"13.1.7"
+	],
+	"91.0.4472.164": [
+		"13.1.8",
+		"13.1.9",
+		"13.2.0",
+		"13.2.1",
+		"13.2.2",
+		"13.2.3",
+		"13.3.0",
+		"13.4.0",
+		"13.5.0",
+		"13.5.1"
+	],
+	"92.0.4511.0": [
+		"14.0.0-beta.1",
+		"14.0.0-beta.2",
+		"14.0.0-beta.3",
+		"14.0.0-nightly.20210520",
+		"14.0.0-nightly.20210523",
+		"14.0.0-nightly.20210524",
+		"15.0.0-nightly.20210527",
+		"15.0.0-nightly.20210528",
+		"15.0.0-nightly.20210531",
+		"15.0.0-nightly.20210601",
+		"15.0.0-nightly.20210602"
+	],
+	"93.0.4536.0": [
+		"14.0.0-beta.5",
+		"14.0.0-beta.6",
+		"14.0.0-beta.7",
+		"14.0.0-beta.8",
+		"15.0.0-nightly.20210609",
+		"15.0.0-nightly.20210610",
+		"15.0.0-nightly.20210611",
+		"15.0.0-nightly.20210614",
+		"15.0.0-nightly.20210615",
+		"15.0.0-nightly.20210616"
+	],
+	"93.0.4539.0": [
+		"14.0.0-beta.9",
+		"14.0.0-beta.10",
+		"15.0.0-nightly.20210617",
+		"15.0.0-nightly.20210618",
+		"15.0.0-nightly.20210621",
+		"15.0.0-nightly.20210622"
+	],
+	"93.0.4557.4": [
+		"14.0.0-beta.11",
+		"14.0.0-beta.12"
+	],
+	"93.0.4566.0": [
+		"14.0.0-beta.13",
+		"14.0.0-beta.14",
+		"14.0.0-beta.15",
+		"14.0.0-beta.16",
+		"14.0.0-beta.17",
+		"15.0.0-alpha.1",
+		"15.0.0-alpha.2",
+		"15.0.0-nightly.20210706",
+		"15.0.0-nightly.20210707",
+		"15.0.0-nightly.20210708",
+		"15.0.0-nightly.20210709",
+		"15.0.0-nightly.20210712",
+		"15.0.0-nightly.20210713",
+		"15.0.0-nightly.20210714",
+		"15.0.0-nightly.20210715",
+		"15.0.0-nightly.20210716",
+		"15.0.0-nightly.20210719",
+		"15.0.0-nightly.20210720",
+		"15.0.0-nightly.20210721",
+		"16.0.0-nightly.20210722",
+		"16.0.0-nightly.20210723",
+		"16.0.0-nightly.20210726"
+	],
+	"93.0.4577.15": [
+		"14.0.0-beta.18",
+		"14.0.0-beta.19",
+		"14.0.0-beta.20",
+		"14.0.0-beta.21"
+	],
+	"93.0.4577.25": [
+		"14.0.0-beta.22",
+		"14.0.0-beta.23"
+	],
+	"93.0.4577.51": [
+		"14.0.0-beta.24",
+		"14.0.0-beta.25"
+	],
+	"92.0.4475.0": [
+		"14.0.0-nightly.20210426",
+		"14.0.0-nightly.20210427"
+	],
+	"92.0.4488.0": [
+		"14.0.0-nightly.20210430",
+		"14.0.0-nightly.20210503"
+	],
+	"92.0.4496.0": [
+		"14.0.0-nightly.20210505"
+	],
+	"92.0.4498.0": [
+		"14.0.0-nightly.20210506"
+	],
+	"92.0.4499.0": [
+		"14.0.0-nightly.20210507",
+		"14.0.0-nightly.20210510",
+		"14.0.0-nightly.20210511",
+		"14.0.0-nightly.20210512",
+		"14.0.0-nightly.20210513"
+	],
+	"92.0.4505.0": [
+		"14.0.0-nightly.20210514",
+		"14.0.0-nightly.20210517",
+		"14.0.0-nightly.20210518",
+		"14.0.0-nightly.20210519"
+	],
+	"93.0.4577.58": [
+		"14.0.0"
+	],
+	"93.0.4577.63": [
+		"14.0.1"
+	],
+	"93.0.4577.82": [
+		"14.0.2",
+		"14.1.0"
+	],
+	"94.0.4584.0": [
+		"15.0.0-alpha.3",
+		"15.0.0-alpha.4",
+		"15.0.0-alpha.5",
+		"15.0.0-alpha.6",
+		"16.0.0-nightly.20210727",
+		"16.0.0-nightly.20210728",
+		"16.0.0-nightly.20210729",
+		"16.0.0-nightly.20210730",
+		"16.0.0-nightly.20210802",
+		"16.0.0-nightly.20210803",
+		"16.0.0-nightly.20210804",
+		"16.0.0-nightly.20210805",
+		"16.0.0-nightly.20210806",
+		"16.0.0-nightly.20210809",
+		"16.0.0-nightly.20210810",
+		"16.0.0-nightly.20210811"
+	],
+	"94.0.4590.2": [
+		"15.0.0-alpha.7",
+		"15.0.0-alpha.8",
+		"15.0.0-alpha.9",
+		"16.0.0-nightly.20210812",
+		"16.0.0-nightly.20210813",
+		"16.0.0-nightly.20210816",
+		"16.0.0-nightly.20210817",
+		"16.0.0-nightly.20210818",
+		"16.0.0-nightly.20210819",
+		"16.0.0-nightly.20210820",
+		"16.0.0-nightly.20210823"
+	],
+	"94.0.4606.12": [
+		"15.0.0-alpha.10"
+	],
+	"94.0.4606.20": [
+		"15.0.0-beta.1",
+		"15.0.0-beta.2"
+	],
+	"94.0.4606.31": [
+		"15.0.0-beta.3",
+		"15.0.0-beta.4",
+		"15.0.0-beta.5",
+		"15.0.0-beta.6",
+		"15.0.0-beta.7"
+	],
+	"93.0.4530.0": [
+		"15.0.0-nightly.20210603",
+		"15.0.0-nightly.20210604"
+	],
+	"93.0.4535.0": [
+		"15.0.0-nightly.20210608"
+	],
+	"93.0.4550.0": [
+		"15.0.0-nightly.20210623",
+		"15.0.0-nightly.20210624"
+	],
+	"93.0.4552.0": [
+		"15.0.0-nightly.20210625",
+		"15.0.0-nightly.20210628",
+		"15.0.0-nightly.20210629"
+	],
+	"93.0.4558.0": [
+		"15.0.0-nightly.20210630",
+		"15.0.0-nightly.20210701",
+		"15.0.0-nightly.20210702",
+		"15.0.0-nightly.20210705"
+	],
+	"94.0.4606.51": [
+		"15.0.0"
+	],
+	"94.0.4606.61": [
+		"15.1.0",
+		"15.1.1"
+	],
+	"95.0.4629.0": [
+		"16.0.0-alpha.1",
+		"16.0.0-alpha.2",
+		"16.0.0-alpha.3",
+		"16.0.0-alpha.4",
+		"16.0.0-alpha.5",
+		"16.0.0-alpha.6",
+		"16.0.0-nightly.20210902",
+		"16.0.0-nightly.20210903",
+		"16.0.0-nightly.20210906",
+		"16.0.0-nightly.20210907",
+		"16.0.0-nightly.20210908",
+		"16.0.0-nightly.20210909",
+		"16.0.0-nightly.20210910",
+		"16.0.0-nightly.20210913",
+		"16.0.0-nightly.20210914",
+		"16.0.0-nightly.20210915",
+		"16.0.0-nightly.20210916",
+		"16.0.0-nightly.20210917",
+		"16.0.0-nightly.20210920",
+		"16.0.0-nightly.20210921",
+		"16.0.0-nightly.20210922",
+		"17.0.0-nightly.20210923",
+		"17.0.0-nightly.20210924",
+		"17.0.0-nightly.20210927",
+		"17.0.0-nightly.20210928",
+		"17.0.0-nightly.20210929",
+		"17.0.0-nightly.20210930",
+		"17.0.0-nightly.20211001",
+		"17.0.0-nightly.20211004",
+		"17.0.0-nightly.20211005"
+	],
+	"95.0.4612.5": [
+		"16.0.0-nightly.20210824",
+		"16.0.0-nightly.20210825",
+		"16.0.0-nightly.20210826",
+		"16.0.0-nightly.20210827",
+		"16.0.0-nightly.20210830",
+		"16.0.0-nightly.20210831",
+		"16.0.0-nightly.20210901"
+	],
+	"96.0.4647.0": [
+		"17.0.0-nightly.20211006",
+		"17.0.0-nightly.20211007"
 	]
 };
\ No newline at end of file
